"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
from .. import substrait
import typing
import typing_extensions
DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DerivationExpression(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ExpressionFixedChar(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        LENGTH_FIELD_NUMBER: builtins.int
        VARIATION_POINTER_FIELD_NUMBER: builtins.int
        NULLABILITY_FIELD_NUMBER: builtins.int

        @property
        def length(self) -> global___DerivationExpression:
            ...
        variation_pointer: builtins.int
        nullability: substrait.type_pb2.Type.Nullability.ValueType

        def __init__(self, *, length: typing.Optional[global___DerivationExpression]=..., variation_pointer: builtins.int=..., nullability: substrait.type_pb2.Type.Nullability.ValueType=...) -> None:
            ...

        def HasField(self, field_name: typing_extensions.Literal['length', b'length']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing_extensions.Literal['length', b'length', 'nullability', b'nullability', 'variation_pointer', b'variation_pointer']) -> None:
            ...

    class ExpressionVarChar(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        LENGTH_FIELD_NUMBER: builtins.int
        VARIATION_POINTER_FIELD_NUMBER: builtins.int
        NULLABILITY_FIELD_NUMBER: builtins.int

        @property
        def length(self) -> global___DerivationExpression:
            ...
        variation_pointer: builtins.int
        nullability: substrait.type_pb2.Type.Nullability.ValueType

        def __init__(self, *, length: typing.Optional[global___DerivationExpression]=..., variation_pointer: builtins.int=..., nullability: substrait.type_pb2.Type.Nullability.ValueType=...) -> None:
            ...

        def HasField(self, field_name: typing_extensions.Literal['length', b'length']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing_extensions.Literal['length', b'length', 'nullability', b'nullability', 'variation_pointer', b'variation_pointer']) -> None:
            ...

    class ExpressionFixedBinary(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        LENGTH_FIELD_NUMBER: builtins.int
        VARIATION_POINTER_FIELD_NUMBER: builtins.int
        NULLABILITY_FIELD_NUMBER: builtins.int

        @property
        def length(self) -> global___DerivationExpression:
            ...
        variation_pointer: builtins.int
        nullability: substrait.type_pb2.Type.Nullability.ValueType

        def __init__(self, *, length: typing.Optional[global___DerivationExpression]=..., variation_pointer: builtins.int=..., nullability: substrait.type_pb2.Type.Nullability.ValueType=...) -> None:
            ...

        def HasField(self, field_name: typing_extensions.Literal['length', b'length']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing_extensions.Literal['length', b'length', 'nullability', b'nullability', 'variation_pointer', b'variation_pointer']) -> None:
            ...

    class ExpressionDecimal(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        SCALE_FIELD_NUMBER: builtins.int
        PRECISION_FIELD_NUMBER: builtins.int
        VARIATION_POINTER_FIELD_NUMBER: builtins.int
        NULLABILITY_FIELD_NUMBER: builtins.int

        @property
        def scale(self) -> global___DerivationExpression:
            ...

        @property
        def precision(self) -> global___DerivationExpression:
            ...
        variation_pointer: builtins.int
        nullability: substrait.type_pb2.Type.Nullability.ValueType

        def __init__(self, *, scale: typing.Optional[global___DerivationExpression]=..., precision: typing.Optional[global___DerivationExpression]=..., variation_pointer: builtins.int=..., nullability: substrait.type_pb2.Type.Nullability.ValueType=...) -> None:
            ...

        def HasField(self, field_name: typing_extensions.Literal['precision', b'precision', 'scale', b'scale']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing_extensions.Literal['nullability', b'nullability', 'precision', b'precision', 'scale', b'scale', 'variation_pointer', b'variation_pointer']) -> None:
            ...

    class ExpressionStruct(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        TYPES_FIELD_NUMBER: builtins.int
        VARIATION_POINTER_FIELD_NUMBER: builtins.int
        NULLABILITY_FIELD_NUMBER: builtins.int

        @property
        def types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DerivationExpression]:
            ...
        variation_pointer: builtins.int
        nullability: substrait.type_pb2.Type.Nullability.ValueType

        def __init__(self, *, types: typing.Optional[typing.Iterable[global___DerivationExpression]]=..., variation_pointer: builtins.int=..., nullability: substrait.type_pb2.Type.Nullability.ValueType=...) -> None:
            ...

        def ClearField(self, field_name: typing_extensions.Literal['nullability', b'nullability', 'types', b'types', 'variation_pointer', b'variation_pointer']) -> None:
            ...

    class ExpressionNamedStruct(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        NAMES_FIELD_NUMBER: builtins.int
        STRUCT_FIELD_NUMBER: builtins.int

        @property
        def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
            ...

        @property
        def struct(self) -> global___DerivationExpression.ExpressionStruct:
            ...

        def __init__(self, *, names: typing.Optional[typing.Iterable[typing.Text]]=..., struct: typing.Optional[global___DerivationExpression.ExpressionStruct]=...) -> None:
            ...

        def HasField(self, field_name: typing_extensions.Literal['struct', b'struct']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing_extensions.Literal['names', b'names', 'struct', b'struct']) -> None:
            ...

    class ExpressionList(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        TYPE_FIELD_NUMBER: builtins.int
        VARIATION_POINTER_FIELD_NUMBER: builtins.int
        NULLABILITY_FIELD_NUMBER: builtins.int

        @property
        def type(self) -> global___DerivationExpression:
            ...
        variation_pointer: builtins.int
        nullability: substrait.type_pb2.Type.Nullability.ValueType

        def __init__(self, *, type: typing.Optional[global___DerivationExpression]=..., variation_pointer: builtins.int=..., nullability: substrait.type_pb2.Type.Nullability.ValueType=...) -> None:
            ...

        def HasField(self, field_name: typing_extensions.Literal['type', b'type']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing_extensions.Literal['nullability', b'nullability', 'type', b'type', 'variation_pointer', b'variation_pointer']) -> None:
            ...

    class ExpressionMap(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        VARIATION_POINTER_FIELD_NUMBER: builtins.int
        NULLABILITY_FIELD_NUMBER: builtins.int

        @property
        def key(self) -> global___DerivationExpression:
            ...

        @property
        def value(self) -> global___DerivationExpression:
            ...
        variation_pointer: builtins.int
        nullability: substrait.type_pb2.Type.Nullability.ValueType

        def __init__(self, *, key: typing.Optional[global___DerivationExpression]=..., value: typing.Optional[global___DerivationExpression]=..., variation_pointer: builtins.int=..., nullability: substrait.type_pb2.Type.Nullability.ValueType=...) -> None:
            ...

        def HasField(self, field_name: typing_extensions.Literal['key', b'key', 'value', b'value']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing_extensions.Literal['key', b'key', 'nullability', b'nullability', 'value', b'value', 'variation_pointer', b'variation_pointer']) -> None:
            ...

    class IfElse(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        IF_CONDITION_FIELD_NUMBER: builtins.int
        IF_RETURN_FIELD_NUMBER: builtins.int
        ELSE_RETURN_FIELD_NUMBER: builtins.int

        @property
        def if_condition(self) -> global___DerivationExpression:
            ...

        @property
        def if_return(self) -> global___DerivationExpression:
            ...

        @property
        def else_return(self) -> global___DerivationExpression:
            ...

        def __init__(self, *, if_condition: typing.Optional[global___DerivationExpression]=..., if_return: typing.Optional[global___DerivationExpression]=..., else_return: typing.Optional[global___DerivationExpression]=...) -> None:
            ...

        def HasField(self, field_name: typing_extensions.Literal['else_return', b'else_return', 'if_condition', b'if_condition', 'if_return', b'if_return']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing_extensions.Literal['else_return', b'else_return', 'if_condition', b'if_condition', 'if_return', b'if_return']) -> None:
            ...

    class UnaryOp(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _UnaryOpType:
            ValueType = typing.NewType('ValueType', builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _UnaryOpTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DerivationExpression.UnaryOp._UnaryOpType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNARY_OP_TYPE_UNSPECIFIED: DerivationExpression.UnaryOp._UnaryOpType.ValueType
            UNARY_OP_TYPE_BOOLEAN_NOT: DerivationExpression.UnaryOp._UnaryOpType.ValueType

        class UnaryOpType(_UnaryOpType, metaclass=_UnaryOpTypeEnumTypeWrapper):
            pass
        UNARY_OP_TYPE_UNSPECIFIED: DerivationExpression.UnaryOp.UnaryOpType.ValueType
        UNARY_OP_TYPE_BOOLEAN_NOT: DerivationExpression.UnaryOp.UnaryOpType.ValueType
        OP_TYPE_FIELD_NUMBER: builtins.int
        ARG_FIELD_NUMBER: builtins.int
        op_type: global___DerivationExpression.UnaryOp.UnaryOpType.ValueType

        @property
        def arg(self) -> global___DerivationExpression:
            ...

        def __init__(self, *, op_type: global___DerivationExpression.UnaryOp.UnaryOpType.ValueType=..., arg: typing.Optional[global___DerivationExpression]=...) -> None:
            ...

        def HasField(self, field_name: typing_extensions.Literal['arg', b'arg']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing_extensions.Literal['arg', b'arg', 'op_type', b'op_type']) -> None:
            ...

    class BinaryOp(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _BinaryOpType:
            ValueType = typing.NewType('ValueType', builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _BinaryOpTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DerivationExpression.BinaryOp._BinaryOpType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            BINARY_OP_TYPE_UNSPECIFIED: DerivationExpression.BinaryOp._BinaryOpType.ValueType
            BINARY_OP_TYPE_PLUS: DerivationExpression.BinaryOp._BinaryOpType.ValueType
            BINARY_OP_TYPE_MINUS: DerivationExpression.BinaryOp._BinaryOpType.ValueType
            BINARY_OP_TYPE_MULTIPLY: DerivationExpression.BinaryOp._BinaryOpType.ValueType
            BINARY_OP_TYPE_DIVIDE: DerivationExpression.BinaryOp._BinaryOpType.ValueType
            BINARY_OP_TYPE_MIN: DerivationExpression.BinaryOp._BinaryOpType.ValueType
            BINARY_OP_TYPE_MAX: DerivationExpression.BinaryOp._BinaryOpType.ValueType
            BINARY_OP_TYPE_GREATER_THAN: DerivationExpression.BinaryOp._BinaryOpType.ValueType
            BINARY_OP_TYPE_LESS_THAN: DerivationExpression.BinaryOp._BinaryOpType.ValueType
            BINARY_OP_TYPE_AND: DerivationExpression.BinaryOp._BinaryOpType.ValueType
            BINARY_OP_TYPE_OR: DerivationExpression.BinaryOp._BinaryOpType.ValueType
            BINARY_OP_TYPE_EQUALS: DerivationExpression.BinaryOp._BinaryOpType.ValueType
            BINARY_OP_TYPE_COVERS: DerivationExpression.BinaryOp._BinaryOpType.ValueType

        class BinaryOpType(_BinaryOpType, metaclass=_BinaryOpTypeEnumTypeWrapper):
            pass
        BINARY_OP_TYPE_UNSPECIFIED: DerivationExpression.BinaryOp.BinaryOpType.ValueType
        BINARY_OP_TYPE_PLUS: DerivationExpression.BinaryOp.BinaryOpType.ValueType
        BINARY_OP_TYPE_MINUS: DerivationExpression.BinaryOp.BinaryOpType.ValueType
        BINARY_OP_TYPE_MULTIPLY: DerivationExpression.BinaryOp.BinaryOpType.ValueType
        BINARY_OP_TYPE_DIVIDE: DerivationExpression.BinaryOp.BinaryOpType.ValueType
        BINARY_OP_TYPE_MIN: DerivationExpression.BinaryOp.BinaryOpType.ValueType
        BINARY_OP_TYPE_MAX: DerivationExpression.BinaryOp.BinaryOpType.ValueType
        BINARY_OP_TYPE_GREATER_THAN: DerivationExpression.BinaryOp.BinaryOpType.ValueType
        BINARY_OP_TYPE_LESS_THAN: DerivationExpression.BinaryOp.BinaryOpType.ValueType
        BINARY_OP_TYPE_AND: DerivationExpression.BinaryOp.BinaryOpType.ValueType
        BINARY_OP_TYPE_OR: DerivationExpression.BinaryOp.BinaryOpType.ValueType
        BINARY_OP_TYPE_EQUALS: DerivationExpression.BinaryOp.BinaryOpType.ValueType
        BINARY_OP_TYPE_COVERS: DerivationExpression.BinaryOp.BinaryOpType.ValueType
        OP_TYPE_FIELD_NUMBER: builtins.int
        ARG1_FIELD_NUMBER: builtins.int
        ARG2_FIELD_NUMBER: builtins.int
        op_type: global___DerivationExpression.BinaryOp.BinaryOpType.ValueType

        @property
        def arg1(self) -> global___DerivationExpression:
            ...

        @property
        def arg2(self) -> global___DerivationExpression:
            ...

        def __init__(self, *, op_type: global___DerivationExpression.BinaryOp.BinaryOpType.ValueType=..., arg1: typing.Optional[global___DerivationExpression]=..., arg2: typing.Optional[global___DerivationExpression]=...) -> None:
            ...

        def HasField(self, field_name: typing_extensions.Literal['arg1', b'arg1', 'arg2', b'arg2']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing_extensions.Literal['arg1', b'arg1', 'arg2', b'arg2', 'op_type', b'op_type']) -> None:
            ...

    class ReturnProgram(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class Assignment(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor
            NAME_FIELD_NUMBER: builtins.int
            EXPRESSION_FIELD_NUMBER: builtins.int
            name: typing.Text

            @property
            def expression(self) -> global___DerivationExpression:
                ...

            def __init__(self, *, name: typing.Text=..., expression: typing.Optional[global___DerivationExpression]=...) -> None:
                ...

            def HasField(self, field_name: typing_extensions.Literal['expression', b'expression']) -> builtins.bool:
                ...

            def ClearField(self, field_name: typing_extensions.Literal['expression', b'expression', 'name', b'name']) -> None:
                ...
        ASSIGNMENTS_FIELD_NUMBER: builtins.int
        FINAL_EXPRESSION_FIELD_NUMBER: builtins.int

        @property
        def assignments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DerivationExpression.ReturnProgram.Assignment]:
            ...

        @property
        def final_expression(self) -> global___DerivationExpression:
            ...

        def __init__(self, *, assignments: typing.Optional[typing.Iterable[global___DerivationExpression.ReturnProgram.Assignment]]=..., final_expression: typing.Optional[global___DerivationExpression]=...) -> None:
            ...

        def HasField(self, field_name: typing_extensions.Literal['final_expression', b'final_expression']) -> builtins.bool:
            ...

        def ClearField(self, field_name: typing_extensions.Literal['assignments', b'assignments', 'final_expression', b'final_expression']) -> None:
            ...
    BOOL_FIELD_NUMBER: builtins.int
    I8_FIELD_NUMBER: builtins.int
    I16_FIELD_NUMBER: builtins.int
    I32_FIELD_NUMBER: builtins.int
    I64_FIELD_NUMBER: builtins.int
    FP32_FIELD_NUMBER: builtins.int
    FP64_FIELD_NUMBER: builtins.int
    STRING_FIELD_NUMBER: builtins.int
    BINARY_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    DATE_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    INTERVAL_YEAR_FIELD_NUMBER: builtins.int
    INTERVAL_DAY_FIELD_NUMBER: builtins.int
    TIMESTAMP_TZ_FIELD_NUMBER: builtins.int
    UUID_FIELD_NUMBER: builtins.int
    FIXED_CHAR_FIELD_NUMBER: builtins.int
    VARCHAR_FIELD_NUMBER: builtins.int
    FIXED_BINARY_FIELD_NUMBER: builtins.int
    DECIMAL_FIELD_NUMBER: builtins.int
    STRUCT_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    MAP_FIELD_NUMBER: builtins.int
    USER_DEFINED_POINTER_FIELD_NUMBER: builtins.int
    TYPE_PARAMETER_NAME_FIELD_NUMBER: builtins.int
    INTEGER_PARAMETER_NAME_FIELD_NUMBER: builtins.int
    INTEGER_LITERAL_FIELD_NUMBER: builtins.int
    UNARY_OP_FIELD_NUMBER: builtins.int
    BINARY_OP_FIELD_NUMBER: builtins.int
    IF_ELSE_FIELD_NUMBER: builtins.int
    RETURN_PROGRAM_FIELD_NUMBER: builtins.int

    @property
    def bool(self) -> substrait.type_pb2.Type.Boolean:
        ...

    @property
    def i8(self) -> substrait.type_pb2.Type.I8:
        ...

    @property
    def i16(self) -> substrait.type_pb2.Type.I16:
        ...

    @property
    def i32(self) -> substrait.type_pb2.Type.I32:
        ...

    @property
    def i64(self) -> substrait.type_pb2.Type.I64:
        ...

    @property
    def fp32(self) -> substrait.type_pb2.Type.FP32:
        ...

    @property
    def fp64(self) -> substrait.type_pb2.Type.FP64:
        ...

    @property
    def string(self) -> substrait.type_pb2.Type.String:
        ...

    @property
    def binary(self) -> substrait.type_pb2.Type.Binary:
        ...

    @property
    def timestamp(self) -> substrait.type_pb2.Type.Timestamp:
        ...

    @property
    def date(self) -> substrait.type_pb2.Type.Date:
        ...

    @property
    def time(self) -> substrait.type_pb2.Type.Time:
        ...

    @property
    def interval_year(self) -> substrait.type_pb2.Type.IntervalYear:
        ...

    @property
    def interval_day(self) -> substrait.type_pb2.Type.IntervalDay:
        ...

    @property
    def timestamp_tz(self) -> substrait.type_pb2.Type.TimestampTZ:
        ...

    @property
    def uuid(self) -> substrait.type_pb2.Type.UUID:
        ...

    @property
    def fixed_char(self) -> global___DerivationExpression.ExpressionFixedChar:
        ...

    @property
    def varchar(self) -> global___DerivationExpression.ExpressionVarChar:
        ...

    @property
    def fixed_binary(self) -> global___DerivationExpression.ExpressionFixedBinary:
        ...

    @property
    def decimal(self) -> global___DerivationExpression.ExpressionDecimal:
        ...

    @property
    def struct(self) -> global___DerivationExpression.ExpressionStruct:
        ...

    @property
    def list(self) -> global___DerivationExpression.ExpressionList:
        ...

    @property
    def map(self) -> global___DerivationExpression.ExpressionMap:
        ...
    user_defined_pointer: builtins.int
    type_parameter_name: typing.Text
    integer_parameter_name: typing.Text
    integer_literal: builtins.int

    @property
    def unary_op(self) -> global___DerivationExpression.UnaryOp:
        ...

    @property
    def binary_op(self) -> global___DerivationExpression.BinaryOp:
        ...

    @property
    def if_else(self) -> global___DerivationExpression.IfElse:
        ...

    @property
    def return_program(self) -> global___DerivationExpression.ReturnProgram:
        ...

    def __init__(self, *, bool: typing.Optional[substrait.type_pb2.Type.Boolean]=..., i8: typing.Optional[substrait.type_pb2.Type.I8]=..., i16: typing.Optional[substrait.type_pb2.Type.I16]=..., i32: typing.Optional[substrait.type_pb2.Type.I32]=..., i64: typing.Optional[substrait.type_pb2.Type.I64]=..., fp32: typing.Optional[substrait.type_pb2.Type.FP32]=..., fp64: typing.Optional[substrait.type_pb2.Type.FP64]=..., string: typing.Optional[substrait.type_pb2.Type.String]=..., binary: typing.Optional[substrait.type_pb2.Type.Binary]=..., timestamp: typing.Optional[substrait.type_pb2.Type.Timestamp]=..., date: typing.Optional[substrait.type_pb2.Type.Date]=..., time: typing.Optional[substrait.type_pb2.Type.Time]=..., interval_year: typing.Optional[substrait.type_pb2.Type.IntervalYear]=..., interval_day: typing.Optional[substrait.type_pb2.Type.IntervalDay]=..., timestamp_tz: typing.Optional[substrait.type_pb2.Type.TimestampTZ]=..., uuid: typing.Optional[substrait.type_pb2.Type.UUID]=..., fixed_char: typing.Optional[global___DerivationExpression.ExpressionFixedChar]=..., varchar: typing.Optional[global___DerivationExpression.ExpressionVarChar]=..., fixed_binary: typing.Optional[global___DerivationExpression.ExpressionFixedBinary]=..., decimal: typing.Optional[global___DerivationExpression.ExpressionDecimal]=..., struct: typing.Optional[global___DerivationExpression.ExpressionStruct]=..., list: typing.Optional[global___DerivationExpression.ExpressionList]=..., map: typing.Optional[global___DerivationExpression.ExpressionMap]=..., user_defined_pointer: builtins.int=..., type_parameter_name: typing.Text=..., integer_parameter_name: typing.Text=..., integer_literal: builtins.int=..., unary_op: typing.Optional[global___DerivationExpression.UnaryOp]=..., binary_op: typing.Optional[global___DerivationExpression.BinaryOp]=..., if_else: typing.Optional[global___DerivationExpression.IfElse]=..., return_program: typing.Optional[global___DerivationExpression.ReturnProgram]=...) -> None:
        ...

    def HasField(self, field_name: typing_extensions.Literal['binary', b'binary', 'binary_op', b'binary_op', 'bool', b'bool', 'date', b'date', 'decimal', b'decimal', 'fixed_binary', b'fixed_binary', 'fixed_char', b'fixed_char', 'fp32', b'fp32', 'fp64', b'fp64', 'i16', b'i16', 'i32', b'i32', 'i64', b'i64', 'i8', b'i8', 'if_else', b'if_else', 'integer_literal', b'integer_literal', 'integer_parameter_name', b'integer_parameter_name', 'interval_day', b'interval_day', 'interval_year', b'interval_year', 'kind', b'kind', 'list', b'list', 'map', b'map', 'return_program', b'return_program', 'string', b'string', 'struct', b'struct', 'time', b'time', 'timestamp', b'timestamp', 'timestamp_tz', b'timestamp_tz', 'type_parameter_name', b'type_parameter_name', 'unary_op', b'unary_op', 'user_defined_pointer', b'user_defined_pointer', 'uuid', b'uuid', 'varchar', b'varchar']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing_extensions.Literal['binary', b'binary', 'binary_op', b'binary_op', 'bool', b'bool', 'date', b'date', 'decimal', b'decimal', 'fixed_binary', b'fixed_binary', 'fixed_char', b'fixed_char', 'fp32', b'fp32', 'fp64', b'fp64', 'i16', b'i16', 'i32', b'i32', 'i64', b'i64', 'i8', b'i8', 'if_else', b'if_else', 'integer_literal', b'integer_literal', 'integer_parameter_name', b'integer_parameter_name', 'interval_day', b'interval_day', 'interval_year', b'interval_year', 'kind', b'kind', 'list', b'list', 'map', b'map', 'return_program', b'return_program', 'string', b'string', 'struct', b'struct', 'time', b'time', 'timestamp', b'timestamp', 'timestamp_tz', b'timestamp_tz', 'type_parameter_name', b'type_parameter_name', 'unary_op', b'unary_op', 'user_defined_pointer', b'user_defined_pointer', 'uuid', b'uuid', 'varchar', b'varchar']) -> None:
        ...

    def WhichOneof(self, oneof_group: typing_extensions.Literal['kind', b'kind']) -> typing.Optional[typing_extensions.Literal['bool', 'i8', 'i16', 'i32', 'i64', 'fp32', 'fp64', 'string', 'binary', 'timestamp', 'date', 'time', 'interval_year', 'interval_day', 'timestamp_tz', 'uuid', 'fixed_char', 'varchar', 'fixed_binary', 'decimal', 'struct', 'list', 'map', 'user_defined_pointer', 'type_parameter_name', 'integer_parameter_name', 'integer_literal', 'unary_op', 'binary_op', 'if_else', 'return_program']]:
        ...
global___DerivationExpression = DerivationExpression


from . import parameterized_types_pb2
from . import capabilities_pb2
from . import function_pb2
from . import plan_pb2
from . import type_pb2
from . import algebra_pb2
from . import type_expressions_pb2
from . import extensions



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
from .. import substrait
from .. import substrait
import typing
import typing_extensions
DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PlanRel(google.protobuf.message.Message):
    """Either a relation or root relation"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REL_FIELD_NUMBER: builtins.int
    ROOT_FIELD_NUMBER: builtins.int

    @property
    def rel(self) -> substrait.algebra_pb2.Rel:
        """Any relation"""
        pass

    @property
    def root(self) -> substrait.algebra_pb2.RelRoot:
        """The root of a relation tree"""
        pass

    def __init__(self, *, rel: typing.Optional[substrait.algebra_pb2.Rel]=..., root: typing.Optional[substrait.algebra_pb2.RelRoot]=...) -> None:
        ...

    def HasField(self, field_name: typing_extensions.Literal['rel', b'rel', 'rel_type', b'rel_type', 'root', b'root']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing_extensions.Literal['rel', b'rel', 'rel_type', b'rel_type', 'root', b'root']) -> None:
        ...

    def WhichOneof(self, oneof_group: typing_extensions.Literal['rel_type', b'rel_type']) -> typing.Optional[typing_extensions.Literal['rel', 'root']]:
        ...
global___PlanRel = PlanRel

class Plan(google.protobuf.message.Message):
    """Describe a set of operations to complete.
    For compactness sake, identifiers are normalized at the plan level.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EXTENSION_URIS_FIELD_NUMBER: builtins.int
    EXTENSIONS_FIELD_NUMBER: builtins.int
    RELATIONS_FIELD_NUMBER: builtins.int
    ADVANCED_EXTENSIONS_FIELD_NUMBER: builtins.int
    EXPECTED_TYPE_URLS_FIELD_NUMBER: builtins.int

    @property
    def extension_uris(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[substrait.extensions.extensions_pb2.SimpleExtensionURI]:
        """a list of yaml specifications this plan may depend on"""
        pass

    @property
    def extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[substrait.extensions.extensions_pb2.SimpleExtensionDeclaration]:
        """a list of extensions this plan may depend on"""
        pass

    @property
    def relations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlanRel]:
        """one or more relation trees that are associated with this plan."""
        pass

    @property
    def advanced_extensions(self) -> substrait.extensions.extensions_pb2.AdvancedExtension:
        """additional extensions associated with this plan."""
        pass

    @property
    def expected_type_urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """A list of com.google.Any entities that this plan may use. Can be used to
        warn if some embedded message types are unknown. Note that this list may
        include message types that are ignorable (optimizations) or that are
        unused. In many cases, a consumer may be able to work with a plan even if
        one or more message types defined here are unknown.
        """
        pass

    def __init__(self, *, extension_uris: typing.Optional[typing.Iterable[substrait.extensions.extensions_pb2.SimpleExtensionURI]]=..., extensions: typing.Optional[typing.Iterable[substrait.extensions.extensions_pb2.SimpleExtensionDeclaration]]=..., relations: typing.Optional[typing.Iterable[global___PlanRel]]=..., advanced_extensions: typing.Optional[substrait.extensions.extensions_pb2.AdvancedExtension]=..., expected_type_urls: typing.Optional[typing.Iterable[typing.Text]]=...) -> None:
        ...

    def HasField(self, field_name: typing_extensions.Literal['advanced_extensions', b'advanced_extensions']) -> builtins.bool:
        ...

    def ClearField(self, field_name: typing_extensions.Literal['advanced_extensions', b'advanced_extensions', 'expected_type_urls', b'expected_type_urls', 'extension_uris', b'extension_uris', 'extensions', b'extensions', 'relations', b'relations']) -> None:
        ...
global___Plan = Plan


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1csubstrait/capabilities.proto\x12\tsubstrait"\xec\x02\n\x0cCapabilities\x12-\n\x12substrait_versions\x18\x01 \x03(\tR\x11substraitVersions\x12?\n\x1cadvanced_extension_type_urls\x18\x02 \x03(\tR\x19advancedExtensionTypeUrls\x12T\n\x11simple_extensions\x18\x03 \x03(\x0b2\'.substrait.Capabilities.SimpleExtensionR\x10simpleExtensions\x1a\x95\x01\n\x0fSimpleExtension\x12\x10\n\x03uri\x18\x01 \x01(\tR\x03uri\x12#\n\rfunction_keys\x18\x02 \x03(\tR\x0cfunctionKeys\x12\x1b\n\ttype_keys\x18\x03 \x03(\tR\x08typeKeys\x12.\n\x13type_variation_keys\x18\x04 \x03(\tR\x11typeVariationKeysB+\n\x12io.substrait.protoP\x01\xaa\x02\x12Substrait.Protobufb\x06proto3')
_CAPABILITIES = DESCRIPTOR.message_types_by_name['Capabilities']
_CAPABILITIES_SIMPLEEXTENSION = _CAPABILITIES.nested_types_by_name['SimpleExtension']
Capabilities = _reflection.GeneratedProtocolMessageType('Capabilities', (_message.Message,), {'SimpleExtension': _reflection.GeneratedProtocolMessageType('SimpleExtension', (_message.Message,), {'DESCRIPTOR': _CAPABILITIES_SIMPLEEXTENSION, '__module__': 'substrait.capabilities_pb2'}), 'DESCRIPTOR': _CAPABILITIES, '__module__': 'substrait.capabilities_pb2'})
_sym_db.RegisterMessage(Capabilities)
_sym_db.RegisterMessage(Capabilities.SimpleExtension)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x12io.substrait.protoP\x01\xaa\x02\x12Substrait.Protobuf'
    _CAPABILITIES._serialized_start = 44
    _CAPABILITIES._serialized_end = 408
    _CAPABILITIES_SIMPLEEXTENSION._serialized_start = 259
    _CAPABILITIES_SIMPLEEXTENSION._serialized_end = 408


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ..substrait import type_pb2 as substrait_dot_type__pb2
from ..substrait import parameterized_types_pb2 as substrait_dot_parameterized__types__pb2
from ..substrait import type_expressions_pb2 as substrait_dot_type__expressions__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18substrait/function.proto\x12\tsubstrait\x1a\x14substrait/type.proto\x1a#substrait/parameterized_types.proto\x1a substrait/type_expressions.proto"\xd9\x19\n\x11FunctionSignature\x1a\xbc\x02\n\x10FinalArgVariadic\x12\x19\n\x08min_args\x18\x01 \x01(\x03R\x07minArgs\x12\x19\n\x08max_args\x18\x02 \x01(\x03R\x07maxArgs\x12d\n\x0bconsistency\x18\x03 \x01(\x0e2B.substrait.FunctionSignature.FinalArgVariadic.ParameterConsistencyR\x0bconsistency"\x8b\x01\n\x14ParameterConsistency\x12%\n!PARAMETER_CONSISTENCY_UNSPECIFIED\x10\x00\x12$\n PARAMETER_CONSISTENCY_CONSISTENT\x10\x01\x12&\n"PARAMETER_CONSISTENCY_INCONSISTENT\x10\x02\x1a\x10\n\x0eFinalArgNormal\x1a\xc8\x04\n\x06Scalar\x12C\n\targuments\x18\x02 \x03(\x0b2%.substrait.FunctionSignature.ArgumentR\targuments\x12\x12\n\x04name\x18\x03 \x03(\tR\x04name\x12J\n\x0bdescription\x18\x04 \x01(\x0b2(.substrait.FunctionSignature.DescriptionR\x0bdescription\x12$\n\rdeterministic\x18\x07 \x01(\x08R\rdeterministic\x12+\n\x11session_dependent\x18\x08 \x01(\x08R\x10sessionDependent\x12@\n\x0boutput_type\x18\t \x01(\x0b2\x1f.substrait.DerivationExpressionR\noutputType\x12K\n\x08variadic\x18\n \x01(\x0b2-.substrait.FunctionSignature.FinalArgVariadicH\x00R\x08variadic\x12E\n\x06normal\x18\x0b \x01(\x0b2+.substrait.FunctionSignature.FinalArgNormalH\x00R\x06normal\x12U\n\x0fimplementations\x18\x0c \x03(\x0b2+.substrait.FunctionSignature.ImplementationR\x0fimplementationsB\x19\n\x17final_variable_behavior\x1a\xbc\x05\n\tAggregate\x12C\n\targuments\x18\x02 \x03(\x0b2%.substrait.FunctionSignature.ArgumentR\targuments\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12J\n\x0bdescription\x18\x04 \x01(\x0b2(.substrait.FunctionSignature.DescriptionR\x0bdescription\x12$\n\rdeterministic\x18\x07 \x01(\x08R\rdeterministic\x12+\n\x11session_dependent\x18\x08 \x01(\x08R\x10sessionDependent\x12@\n\x0boutput_type\x18\t \x01(\x0b2\x1f.substrait.DerivationExpressionR\noutputType\x12K\n\x08variadic\x18\n \x01(\x0b2-.substrait.FunctionSignature.FinalArgVariadicH\x00R\x08variadic\x12E\n\x06normal\x18\x0b \x01(\x0b2+.substrait.FunctionSignature.FinalArgNormalH\x00R\x06normal\x12\x18\n\x07ordered\x18\x0e \x01(\x08R\x07ordered\x12\x17\n\x07max_set\x18\x0c \x01(\x04R\x06maxSet\x12<\n\x11intermediate_type\x18\r \x01(\x0b2\x0f.substrait.TypeR\x10intermediateType\x12U\n\x0fimplementations\x18\x0f \x03(\x0b2+.substrait.FunctionSignature.ImplementationR\x0fimplementationsB\x19\n\x17final_variable_behavior\x1a\xfb\x06\n\x06Window\x12C\n\targuments\x18\x02 \x03(\x0b2%.substrait.FunctionSignature.ArgumentR\targuments\x12\x12\n\x04name\x18\x03 \x03(\tR\x04name\x12J\n\x0bdescription\x18\x04 \x01(\x0b2(.substrait.FunctionSignature.DescriptionR\x0bdescription\x12$\n\rdeterministic\x18\x07 \x01(\x08R\rdeterministic\x12+\n\x11session_dependent\x18\x08 \x01(\x08R\x10sessionDependent\x12L\n\x11intermediate_type\x18\t \x01(\x0b2\x1f.substrait.DerivationExpressionR\x10intermediateType\x12@\n\x0boutput_type\x18\n \x01(\x0b2\x1f.substrait.DerivationExpressionR\noutputType\x12K\n\x08variadic\x18\x10 \x01(\x0b2-.substrait.FunctionSignature.FinalArgVariadicH\x00R\x08variadic\x12E\n\x06normal\x18\x11 \x01(\x0b2+.substrait.FunctionSignature.FinalArgNormalH\x00R\x06normal\x12\x18\n\x07ordered\x18\x0b \x01(\x08R\x07ordered\x12\x17\n\x07max_set\x18\x0c \x01(\x04R\x06maxSet\x12O\n\x0bwindow_type\x18\x0e \x01(\x0e2..substrait.FunctionSignature.Window.WindowTypeR\nwindowType\x12U\n\x0fimplementations\x18\x0f \x03(\x0b2+.substrait.FunctionSignature.ImplementationR\x0fimplementations"_\n\nWindowType\x12\x1b\n\x17WINDOW_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15WINDOW_TYPE_STREAMING\x10\x01\x12\x19\n\x15WINDOW_TYPE_PARTITION\x10\x02B\x19\n\x17final_variable_behavior\x1a=\n\x0bDescription\x12\x1a\n\x08language\x18\x01 \x01(\tR\x08language\x12\x12\n\x04body\x18\x02 \x01(\tR\x04body\x1a\xb1\x01\n\x0eImplementation\x12D\n\x04type\x18\x01 \x01(\x0e20.substrait.FunctionSignature.Implementation.TypeR\x04type\x12\x10\n\x03uri\x18\x02 \x01(\tR\x03uri"G\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11TYPE_WEB_ASSEMBLY\x10\x01\x12\x12\n\x0eTYPE_TRINO_JAR\x10\x02\x1a\xf7\x03\n\x08Argument\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12K\n\x05value\x18\x02 \x01(\x0b23.substrait.FunctionSignature.Argument.ValueArgumentH\x00R\x05value\x12H\n\x04type\x18\x03 \x01(\x0b22.substrait.FunctionSignature.Argument.TypeArgumentH\x00R\x04type\x12H\n\x04enum\x18\x04 \x01(\x0b22.substrait.FunctionSignature.Argument.EnumArgumentH\x00R\x04enum\x1a]\n\rValueArgument\x120\n\x04type\x18\x01 \x01(\x0b2\x1c.substrait.ParameterizedTypeR\x04type\x12\x1a\n\x08constant\x18\x02 \x01(\x08R\x08constant\x1a@\n\x0cTypeArgument\x120\n\x04type\x18\x01 \x01(\x0b2\x1c.substrait.ParameterizedTypeR\x04type\x1aD\n\x0cEnumArgument\x12\x18\n\x07options\x18\x01 \x03(\tR\x07options\x12\x1a\n\x08optional\x18\x02 \x01(\x08R\x08optionalB\x0f\n\rargument_kindB+\n\x12io.substrait.protoP\x01\xaa\x02\x12Substrait.Protobufb\x06proto3')
_FUNCTIONSIGNATURE = DESCRIPTOR.message_types_by_name['FunctionSignature']
_FUNCTIONSIGNATURE_FINALARGVARIADIC = _FUNCTIONSIGNATURE.nested_types_by_name['FinalArgVariadic']
_FUNCTIONSIGNATURE_FINALARGNORMAL = _FUNCTIONSIGNATURE.nested_types_by_name['FinalArgNormal']
_FUNCTIONSIGNATURE_SCALAR = _FUNCTIONSIGNATURE.nested_types_by_name['Scalar']
_FUNCTIONSIGNATURE_AGGREGATE = _FUNCTIONSIGNATURE.nested_types_by_name['Aggregate']
_FUNCTIONSIGNATURE_WINDOW = _FUNCTIONSIGNATURE.nested_types_by_name['Window']
_FUNCTIONSIGNATURE_DESCRIPTION = _FUNCTIONSIGNATURE.nested_types_by_name['Description']
_FUNCTIONSIGNATURE_IMPLEMENTATION = _FUNCTIONSIGNATURE.nested_types_by_name['Implementation']
_FUNCTIONSIGNATURE_ARGUMENT = _FUNCTIONSIGNATURE.nested_types_by_name['Argument']
_FUNCTIONSIGNATURE_ARGUMENT_VALUEARGUMENT = _FUNCTIONSIGNATURE_ARGUMENT.nested_types_by_name['ValueArgument']
_FUNCTIONSIGNATURE_ARGUMENT_TYPEARGUMENT = _FUNCTIONSIGNATURE_ARGUMENT.nested_types_by_name['TypeArgument']
_FUNCTIONSIGNATURE_ARGUMENT_ENUMARGUMENT = _FUNCTIONSIGNATURE_ARGUMENT.nested_types_by_name['EnumArgument']
_FUNCTIONSIGNATURE_FINALARGVARIADIC_PARAMETERCONSISTENCY = _FUNCTIONSIGNATURE_FINALARGVARIADIC.enum_types_by_name['ParameterConsistency']
_FUNCTIONSIGNATURE_WINDOW_WINDOWTYPE = _FUNCTIONSIGNATURE_WINDOW.enum_types_by_name['WindowType']
_FUNCTIONSIGNATURE_IMPLEMENTATION_TYPE = _FUNCTIONSIGNATURE_IMPLEMENTATION.enum_types_by_name['Type']
FunctionSignature = _reflection.GeneratedProtocolMessageType('FunctionSignature', (_message.Message,), {'FinalArgVariadic': _reflection.GeneratedProtocolMessageType('FinalArgVariadic', (_message.Message,), {'DESCRIPTOR': _FUNCTIONSIGNATURE_FINALARGVARIADIC, '__module__': 'substrait.function_pb2'}), 'FinalArgNormal': _reflection.GeneratedProtocolMessageType('FinalArgNormal', (_message.Message,), {'DESCRIPTOR': _FUNCTIONSIGNATURE_FINALARGNORMAL, '__module__': 'substrait.function_pb2'}), 'Scalar': _reflection.GeneratedProtocolMessageType('Scalar', (_message.Message,), {'DESCRIPTOR': _FUNCTIONSIGNATURE_SCALAR, '__module__': 'substrait.function_pb2'}), 'Aggregate': _reflection.GeneratedProtocolMessageType('Aggregate', (_message.Message,), {'DESCRIPTOR': _FUNCTIONSIGNATURE_AGGREGATE, '__module__': 'substrait.function_pb2'}), 'Window': _reflection.GeneratedProtocolMessageType('Window', (_message.Message,), {'DESCRIPTOR': _FUNCTIONSIGNATURE_WINDOW, '__module__': 'substrait.function_pb2'}), 'Description': _reflection.GeneratedProtocolMessageType('Description', (_message.Message,), {'DESCRIPTOR': _FUNCTIONSIGNATURE_DESCRIPTION, '__module__': 'substrait.function_pb2'}), 'Implementation': _reflection.GeneratedProtocolMessageType('Implementation', (_message.Message,), {'DESCRIPTOR': _FUNCTIONSIGNATURE_IMPLEMENTATION, '__module__': 'substrait.function_pb2'}), 'Argument': _reflection.GeneratedProtocolMessageType('Argument', (_message.Message,), {'ValueArgument': _reflection.GeneratedProtocolMessageType('ValueArgument', (_message.Message,), {'DESCRIPTOR': _FUNCTIONSIGNATURE_ARGUMENT_VALUEARGUMENT, '__module__': 'substrait.function_pb2'}), 'TypeArgument': _reflection.GeneratedProtocolMessageType('TypeArgument', (_message.Message,), {'DESCRIPTOR': _FUNCTIONSIGNATURE_ARGUMENT_TYPEARGUMENT, '__module__': 'substrait.function_pb2'}), 'EnumArgument': _reflection.GeneratedProtocolMessageType('EnumArgument', (_message.Message,), {'DESCRIPTOR': _FUNCTIONSIGNATURE_ARGUMENT_ENUMARGUMENT, '__module__': 'substrait.function_pb2'}), 'DESCRIPTOR': _FUNCTIONSIGNATURE_ARGUMENT, '__module__': 'substrait.function_pb2'}), 'DESCRIPTOR': _FUNCTIONSIGNATURE, '__module__': 'substrait.function_pb2'})
_sym_db.RegisterMessage(FunctionSignature)
_sym_db.RegisterMessage(FunctionSignature.FinalArgVariadic)
_sym_db.RegisterMessage(FunctionSignature.FinalArgNormal)
_sym_db.RegisterMessage(FunctionSignature.Scalar)
_sym_db.RegisterMessage(FunctionSignature.Aggregate)
_sym_db.RegisterMessage(FunctionSignature.Window)
_sym_db.RegisterMessage(FunctionSignature.Description)
_sym_db.RegisterMessage(FunctionSignature.Implementation)
_sym_db.RegisterMessage(FunctionSignature.Argument)
_sym_db.RegisterMessage(FunctionSignature.Argument.ValueArgument)
_sym_db.RegisterMessage(FunctionSignature.Argument.TypeArgument)
_sym_db.RegisterMessage(FunctionSignature.Argument.EnumArgument)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x12io.substrait.protoP\x01\xaa\x02\x12Substrait.Protobuf'
    _FUNCTIONSIGNATURE._serialized_start = 133
    _FUNCTIONSIGNATURE._serialized_end = 3422
    _FUNCTIONSIGNATURE_FINALARGVARIADIC._serialized_start = 155
    _FUNCTIONSIGNATURE_FINALARGVARIADIC._serialized_end = 471
    _FUNCTIONSIGNATURE_FINALARGVARIADIC_PARAMETERCONSISTENCY._serialized_start = 332
    _FUNCTIONSIGNATURE_FINALARGVARIADIC_PARAMETERCONSISTENCY._serialized_end = 471
    _FUNCTIONSIGNATURE_FINALARGNORMAL._serialized_start = 473
    _FUNCTIONSIGNATURE_FINALARGNORMAL._serialized_end = 489
    _FUNCTIONSIGNATURE_SCALAR._serialized_start = 492
    _FUNCTIONSIGNATURE_SCALAR._serialized_end = 1076
    _FUNCTIONSIGNATURE_AGGREGATE._serialized_start = 1079
    _FUNCTIONSIGNATURE_AGGREGATE._serialized_end = 1779
    _FUNCTIONSIGNATURE_WINDOW._serialized_start = 1782
    _FUNCTIONSIGNATURE_WINDOW._serialized_end = 2673
    _FUNCTIONSIGNATURE_WINDOW_WINDOWTYPE._serialized_start = 2551
    _FUNCTIONSIGNATURE_WINDOW_WINDOWTYPE._serialized_end = 2646
    _FUNCTIONSIGNATURE_DESCRIPTION._serialized_start = 2675
    _FUNCTIONSIGNATURE_DESCRIPTION._serialized_end = 2736
    _FUNCTIONSIGNATURE_IMPLEMENTATION._serialized_start = 2739
    _FUNCTIONSIGNATURE_IMPLEMENTATION._serialized_end = 2916
    _FUNCTIONSIGNATURE_IMPLEMENTATION_TYPE._serialized_start = 2845
    _FUNCTIONSIGNATURE_IMPLEMENTATION_TYPE._serialized_end = 2916
    _FUNCTIONSIGNATURE_ARGUMENT._serialized_start = 2919
    _FUNCTIONSIGNATURE_ARGUMENT._serialized_end = 3422
    _FUNCTIONSIGNATURE_ARGUMENT_VALUEARGUMENT._serialized_start = 3176
    _FUNCTIONSIGNATURE_ARGUMENT_VALUEARGUMENT._serialized_end = 3269
    _FUNCTIONSIGNATURE_ARGUMENT_TYPEARGUMENT._serialized_start = 3271
    _FUNCTIONSIGNATURE_ARGUMENT_TYPEARGUMENT._serialized_end = 3335
    _FUNCTIONSIGNATURE_ARGUMENT_ENUMARGUMENT._serialized_start = 3337
    _FUNCTIONSIGNATURE_ARGUMENT_ENUMARGUMENT._serialized_end = 3405